@@ -62,10 +62,12 @@ HLSMfixedEF= function(Y,edgeCov = NULL, receiverCov = NULL,senderCov =NULL,FullX
 
 ##prepare covariates#####
 #########################
+	noCOV = FALSE
 	if(!is.null(FullX) & !is.null(edgeCov) &!is.null(receiverCov) & !is.null(senderCov))(stop('FullX cannot be used when nodal or edge covariates are provided'))
 
 	if(is.null(FullX) & is.null(edgeCov) & is.null(receiverCov) & is.null(senderCov)){
 		X = lapply(1:KK,function(x) array(0, dim = c(nn[x],nn[x],1)))
+		noCOV = TRUE
 	}
 
 	if(is.null(FullX)){
@@ -152,18 +154,15 @@ HLSMfixedEF= function(Y,edgeCov = NULL, receiverCov = NULL,senderCov =NULL,FullX
   }
 ##starting values
     if(is.null(initialVals)){
-        Z0 = array(0, dim = c(sum(nn),dd))
-        cc = 1
+	Z0 = list()
         for(i in 1:KK){  
-            cc1 = (cc-1)+nn[i]
             ZZ = t(replicate(nn[i],rnorm(dd,0,1)))
             ZZ[1,]=c(1,0)
             ZZ[2,2]=0
             if(ZZ[2,1] < ZZ[1,1]){
                 ZZ[2,1] = -1*(ZZ[2,1]-ZZ[1,1])+1}
             ZZ[3,2] = abs(ZZ[3,2])
-            Z0[cc:cc1,] = ZZ
-            cc = cc+nn[i]  
+	    Z0[[i]] = ZZ		 
     }
         Z0 = unlist(Z0)
         beta0 = rnorm(PP,0,1)
@@ -226,6 +225,7 @@ HLSMfixedEF= function(Y,edgeCov = NULL, receiverCov = NULL,senderCov =NULL,FullX
 }
     print("Tuning is finished")  
 }
+
     rslt = MCMCfixedEF(nn=nn,PP=PP,KK=KK,dd=dd,XX = XX,YY = YY,ZZ = Z0,TT = TT,
 		beta = beta0 ,intercept = intercept0,alpha = alpha0,MuAlpha = MuAlpha,SigmaAlpha = VarAlpha,
 		MuBeta = MuBeta,SigmaBeta = VarBeta,MuZ = MuZ,VarZ = VarZ,tuneBetaAll = tuneBeta, tuneInt = tuneInt, 
@@ -233,7 +233,22 @@ HLSMfixedEF= function(Y,edgeCov = NULL, receiverCov = NULL,senderCov =NULL,FullX
 		intervention = intervention)
 
     rslt$call = match.call()
-    rslt$tune = list(tuneAlpha = tuneAlpha, tuneZ = tuneZ, tuneBeta = tuneBeta, tuneInt = tuneInt)	
+    if(noCOV == TRUE & intervention == 0){
+		rslt$tune = list(tuneZ = tuneZ, tuneInt = tuneInt)	
+		rslt$draws$Beta = NA
+		rslt$draws$Alpha = NA
+    }
+    if(noCOV == TRUE & intervention == 1){
+	    rslt$tune = list(tuneAlpha = tuneAlpha, tuneZ = tuneZ,tuneInt = tuneInt)
+	    rslt$draws$Beta = NA	
+	}
+    if(noCOV == FALSE & intervention == 0){
+	    rslt$tune = list(tuneBeta = tuneBeta, tuneZ = tuneZ,tuneInt = tuneInt)
+	    rslt$draws$Alpha = NA
+}
+    if(noCOV == FALSE & intervention == 1){
+	    rslt$tune = list(tuneBeta = tuneBeta,tuneAlpha=tuneAlpha,tuneZ = tuneZ,tuneInt = tuneInt)
+}	
     class(rslt) = 'HLSM'
     rslt
 }
